package
Version:
v0.0.5
Opens a new window with list of versions in this module.
Published: Apr 8, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type GStack[T any] struct {
}
func (s *GStack[T]) First() *T
First 获取第一个进入队列的项
func (s *GStack[T]) Push(item T)
Push 入栈
Source Files
¶
Click to show internal directories.
Click to hide internal directories.